Proof

Struct Proof 

#[repr(C)]
pub struct Proof { pub authority: Pubkey, pub claimable_rewards: u64, pub hash: Hash, pub total_hashes: u64, pub total_rewards: u64, }
Proof accounts track a miner’s current hash, claimable rewards, and lifetime stats. Every miner is allowed one proof account which is required by the program to mine or claim rewards.

Fields

authority: Pubkey

The account (i.e. miner) authorized to use this proof.

claimable_rewards: u64

The quantity of tokens this miner may claim from the treasury.

hash: Hash

The proof’s current hash.

total_hashes: u64

The total lifetime hashes provided by this miner.

total_rewards: u64

The total lifetime rewards distributed to this miner.

Implementations

Source

impl Proof

pub fn to_bytes(&self) -> &[u8]