Treasury

Struct Treasury 

#[repr(C)]
pub struct Treasury { pub admin: Pubkey, pub bump: u64, pub difficulty: Hash, pub last_reset_at: i64, pub reward_rate: u64, pub total_claimed_rewards: u64, }
Treasury is a singleton account which manages all program wide variables. It is the mint authority for the Ore token and also the authority of the program-owned token account.

Fields

admin: Pubkey

The admin authority with permission to update the difficulty.

bump: u64

The bump of the treasury account PDA, for signing CPIs.

difficulty: Hash

The hash difficulty.

last_reset_at: i64

The timestamp of the reset invocation.

reward_rate: u64

The reward rate to payout to miners for submiting valid hashes.

total_claimed_rewards: u64

The total lifetime claimed rewards.

Implementations

Source

impl Treasury

pub fn to_bytes(&self) -> &[u8]